@@ -19,7 +19,7 @@ typedef struct branche { /* une branche definie par ses deux extremites */
 	struct noeud *boutb;
 	char *br_label;
 	int *bits;
-	float compteur;
+	float count;
 	struct branche *next_h;
 	} branche;
 #define s_noeud sizeof(struct noeud)
@@ -42,7 +42,7 @@ static int get_br_from_bouts(struct noeud *a, struct noeud *b, branche *);
 static int for_all_branches(struct noeud *centre, struct noeud *origine, branche *branches);
 static int process_branch(struct noeud *cote1, struct noeud *cote2, branche *);
 char *get_br_label(struct noeud *a, struct noeud *b, branche *);
-int is_leave(struct noeud *n);
+inline int is_leave(struct noeud *n);
 void set_leaves(struct noeud *centre, struct noeud *pere, int *bits);
 static int hashvalue(int *bits, int modulo, int totbits);
 void parcourir_branches_each(struct noeud *centre, struct noeud *origine, 
@@ -51,16 +51,23 @@ void process_branch_each(struct noeud *cote1, struct noeud *cote2, float w);
 branche *find_branch(int *bits);
 void add_hash(branche *br);
 int recodeleaves(struct noeud *node, struct noeud *parent, struct noeud **tabtax);
-void use_compteur(branche *branches, int count);	
+static void use_count(branche *branches, int count);	
 void bit0(int *plist, int num);
 void bit1(int *plist, int num);
 int testbit(int *plist, int num);
 void non(int *listnon, int *list, int len);
-void make_strict_consensus(char *tree);
+char *compute_consensus_tree(char **seqnames, int **rows, int branch_count);
+void init_consensus_calculation(int);
+static int recodeleaves_consensus(struct noeud *node, struct noeud *parent, char **seqnames);
+static branche *find_branch_consensus(int *bits);
+static void process_branch_consensus(struct noeud *cote1, struct noeud *cote2);
+static void parcourir_branches_consensus(struct noeud *centre, struct noeud *origine);
+int process_one_consensus_item(char *one_tree, char **seqnames);
+int after_consensus_items(float threshold, int item_count, int ***prows);
 
 /*  extern functions */
 extern char *nextpar(char *pospar);
-extern double place_midpoint_root(struct noeud *from, struct noeud *racine, int fixed_outgroup);
+extern double place_midpoint_root(struct noeud *from, struct noeud *racine, int notu, int fixed_outgroup);
 extern const char *make_binary_or_unrooted(char *arbre);
 
 
@@ -90,7 +97,7 @@ int init_add_bootstrap(char *full_tree)
 	//to have same tree display as without bootstrap, must root it at midpoint and go over branches
 	//from there
 	struct noeud *newroot = (struct noeud *)malloc(sizeof(struct noeud));//deallocated later by free_arbre
-	place_midpoint_root(racine, newroot, FALSE); // root at midpoint
+	place_midpoint_root(racine, newroot, notu, FALSE); // root at midpoint
 	newroot->nom = NULL;
 	struct noeud *v1 = newroot->v1; struct noeud *v2 = newroot->v2;
 	//remove root
@@ -143,7 +150,7 @@ char *finish_add_bootstrap(int replicates)
 	char *arbre1, *arbre2, *arbre3, *arbre, *f1, *f2, *f3, *bootstrap = NULL;
 	struct noeud *r1, *r2, *r3, *r, *r1p, *r2p, *r3p;
 	double l1, l2, l3;
-	use_compteur(mainbranches, replicates);	
+	use_count(mainbranches, replicates);	  
 /*  calcul de son format phylip unrooted */
 	r = racine->v1;
 	if(r->nom != NULL) {//racine->v1 is a leaf
@@ -249,9 +256,11 @@ notu = v + 1 ; /* after this notu = number of OTUs  */
 
 /* allocate all memory */
 tabtax = (struct noeud **)calloc(2*notu-1, sizeof(struct noeud *));
-for(i=0; i<2*notu-1; i++) 
-	*(tabtax+i) = (struct noeud *)calloc(1, s_noeud);
-if(notu > 3) branches = (branche *)calloc(notu-3, sizeof(branche));
+  for (i = 0; i < 2*notu - 1; i++) {
+    tabtax[i] = (struct noeud *)calloc(1, s_noeud);
+    tabtax[i]->rank = i;
+  }
+  if(notu > 3) branches = (branche *)calloc(notu-3, sizeof(branche));
 if(ptaille != NULL) *ptaille = strlen(arbre);
 error = loadphylip(arbre, &rooted, tabtax, branches);
 free(arbre);
@@ -403,7 +412,6 @@ if(*deb != '(') { /* une feuille */
 	p->nom[l] = 0;
 	p->l3 = brlength;
 	p->v1 = p->v2 = p->v3 = NULL;
-	p->rank = nextotu;
 	return p;
 	}
 /* un noeud */
@@ -562,7 +570,7 @@ num = get_br_from_bouts(cote1, cote2, branches);
 if(num == -1) return 1;
 br = &branches[num];
 br->bits = (int *)calloc(w_bits, sizeof(int));
-br->compteur = 0;
+br->count = 0;
 br->next_h = NULL;
 set_leaves(cote1, cote2, br->bits);
 if(! testbit(br->bits, 1) ) {
@@ -598,15 +606,15 @@ a partir de centre et dans la direction opposee a son voisin origine
 {
 if(centre==NULL) return;
 if(centre->v1!=origine) {
-	process_branch_each(centre, centre->v1, w);
+	if (centre->l1) process_branch_each(centre, centre->v1, w);
 	parcourir_branches_each(centre->v1, centre, w);
 	}
 if(centre->v2!=origine) {
-	process_branch_each(centre, centre->v2, w);
+	if (centre->l2) process_branch_each(centre, centre->v2, w);
 	parcourir_branches_each(centre->v2, centre, w);
 	}
 if(centre->v3!=origine) {
-	process_branch_each(centre, centre->v3, w);
+	if (centre->l3) process_branch_each(centre, centre->v3, w);
 	parcourir_branches_each(centre->v3, centre, w);
 	}
 }
@@ -631,7 +639,7 @@ if(! testbit(candidate_bits, 1) ) {
 	if(width > 0) candidate_bits[w_bits - 1] &= word;
 	}
 br = find_branch(candidate_bits);
-if(br != NULL) br->compteur += w;
+if(br != NULL) br->count += w;
 }
 
 
@@ -662,7 +670,7 @@ br->next_h = old;
 }
 
 
-int is_leave(struct noeud *n)
+inline int is_leave(struct noeud *n)
 {
 return n->nom != NULL;
 }
@@ -717,7 +725,7 @@ return 0;
 }
 
 
-void use_compteur(branche *branches, int count)	
+static void use_count(branche *branches, int count)	
 {
 int num;
 char text[20], *p;
@@ -729,7 +737,7 @@ else p = nan;
 for(num = 0; num < totbranches; num++) {
 	br = branches + num;
 	if(br->br_label != NULL) free(br->br_label);
-	if (count) sprintf(text, "%d", (int)(br->compteur * 100. / count + 0.5) );
+	if (count) sprintf(text, "%d", (int)(br->count * 100. / count + 0.5) );
 	br->br_label = strdup(p);
 	}
 }
@@ -758,36 +766,335 @@ int testbit(int *plist, int num)
 
 void non(int *listnon, int *list, int len)
 {
-	
 	int i;
 	for(i=0; i< len; i++)
 		listnon[i]= ~list[i];
 }
 
 
-void make_strict_consensus(char *tree)
-/* input is a tree without br lengths and bootstrap scores
- removes all bootstrap scores, and corresponding () when score is < 100
-to produce a strict consensus tree
-*/
+void et(int *listet, int *list1, int *list2, int len)
 {
-	char *p, *q;
-	int percent;
-	p = tree;
-	while(*(++p) != 0) {
-		if(*p == '(') {
-			q = nextpar(p);
-			sscanf(q + 1, "%d", &percent);
-			if(percent < 100) {//removes clade with score < 100
-				*p = ' ';
-				*q = ' ';
-				}
-			while(TRUE) { //removes bootstrap information
-				q++; 
-				if(isdigit(*q)) *q = ' ';
-				else break;
-				}
-			}
-		}
-	//p = tree;
+  int i;
+  for (i = 0; i < len; i++) listet[i] = list1[i] & list2[i];
+}
+
+
+int irbit(int *pdeblist, int deb, int fin)
+/* 
+ finds next set bit strictly after bit of rank deb and before that of rank fin
+ returns rank of that bit or 0 if none present
+ */
+{
+  unsigned int mot;
+  int *plist, *debw, *finw, retval, d;
+  
+  if(deb >= fin) return 0;
+  finw = pdeblist+(fin-1)/lmot;
+  debw = pdeblist+deb/lmot;
+  
+  plist = debw;
+  mot = *plist;
+  if( (d = deb%lmot) != 0) mot = ( mot>>d ) << d;
+  if(mot == 0 && plist < finw) {
+    do	{
+      if ( *(++plist) != 0) break;
+    }
+    while ( plist < finw );
+    mot = *plist;
+  }
+  if( plist == finw && (d = fin%lmot) != 0 ) { d = lmot-d; mot <<= d; mot >>= d; }
+  
+  if(mot == 0)return 0;
+  retval = (plist-pdeblist)*lmot + 1;
+  while( (mot&1) == 0 ) {
+    mot >>= 1;
+    retval++;
+  }
+  return retval;
+  /*
+   the instruction
+   mot = mot ^ (~(-mot));
+   replaces
+   x...x10...0
+   by
+   0...011...1
+   so that the bit count operation can be used to find first set bit
+   */
+}
+
+
+/* Returns the Newick string of the consensus tree expressed as a list of internal branches,
+ each branch i is represented by a bitlist rows[i] (one bit for each leave, 1s on one side, 0s on the other;
+ rows are standardized with their first bit at 1).
+ The resulting tree is multibranched, unrooted, without length nor branch support.
+ This function could be expanded to output also branch support.
+ Initialization:
+ Build the array of columns: bitlists obtained by reading perpendicular to the rows, one column for each leave.
+ Prepare a string pter for each leave initialized to its name.
+ Prepare row-mask a bitlist with 1 for each column.
+ Prepare column-mask a bitlist with 1 for each row (=branch).
+ Definition: a multibranched cherry is a tree node with only terminal branches on one side;
+ a multibranched cherry is detectable relatively to an internal branch: all columns indexed by
+ the leaves at one or the other side of the branch are identical.
+ Algorithm:
+ For each row (=branch) k, check whether all columns for unmasked leaves i1,i2,... at its 1-side are identical
+ (mask with column-mask when comparing columns);
+ if not, check whether all columns for unmasked leaves i1,i2,... at its 0-side are identical;
+ if not, continue with next branch;
+ if yes, build the Newick form of this cherry: "(i1,i2,...)" and attach it to i1's pter and put 0 to other leave pters.
+ Remove i2,... from row-mask.
+ Remove k from column-mask.
+ Continue until all rows (=branches) have been removed.
+ Finally, 3 or more leaves remain, and the full Newick string concatenates the strings attached to them.
+ */
+char *compute_consensus_tree(char **seqnames, int **rows, int branch_count)
+{
+  // each row represents a tree branch as the bitlist of leaves on one side of the branch
+  int i, j, k, l, w, word, restbranches, j1;
+  char *newtree, *p;
+  char **treeparts = (char**)malloc(notu*sizeof(char*)); 
+  // treepart[i] will be the growing string of subtree containing leave i, or NULL
+  for (i = 0; i < notu; i++) treeparts[i] = strdup(seqnames[i]);
+  int height = (branch_count-1)/lmot + 1; // length of column bitlists
+  int width = (notu-1)/lmot + 1; // length of row bitlists
+  int *column_tmp = (int*)malloc(height*sizeof(int));
+  int *column_mask = (int*)malloc(height*sizeof(int)); // bitlist of remaining rows (= branches)
+  memset(column_mask, -1, height*sizeof(int));
+  int *row_tmp = (int*)malloc(width*sizeof(int));
+  int *row_mask = (int*)malloc(width*sizeof(int)); // bitlist of remaining columns
+  memset(row_mask, -1, width*sizeof(int));
+  /* clear bits after end of bitlist */
+  word = 1;
+  w = notu % lmot;
+  if (w > 1) word = (1 << w) - 1;
+  if (w > 0) row_mask[width - 1] &= word;
+  // build the column table: one column for each tree leave, perpendicular to bit array of rows
+  int **columns = (int**)malloc(notu*sizeof(int*));
+  for (i = 0; i < notu; i++) {
+    columns[i] = (int*)calloc(height, sizeof(int));
+  }
+  for (i = 0; i < branch_count; i++) {
+    for (j = 0; j < notu; j++) {
+      if (testbit(rows[i], j+1)) bit1(columns[j], i+1);
+    }
+  }
+  restbranches = branch_count; // number of remaining branches to process
+  while (restbranches > 0) {
+    for (i = 0; i < branch_count; i++) { // loop for all rows i
+      if (!testbit(column_mask, i+1)) continue; // skip removed rows(=branches)
+      et(row_tmp, rows[i], row_mask, width); // mask out removed leaves
+      j1 = irbit(row_tmp, 0, notu); // find first leave on 1-side of branch i
+      j = j1-1;
+      et(column_tmp, columns[j], column_mask, height); // mask out removed rows
+      while ( (j1 = irbit(row_tmp, j1, notu)) != 0) { // for all other leaves on 1-side of branch i
+	for (k = 0; k < height; k++) { // check that column k is identical-with-mask to column j1-1
+	  if (column_tmp[k] != (columns[j1-1][k] & column_mask[k])) break;
+	}
+	if (k < height) break;
+      }
+      if (k < height) { // columns were not all identical, try columns on 0-side of branch i
+    	non(row_tmp, rows[i], width); // list of leaves on 0-side of branch
+	et(row_tmp, row_tmp, row_mask, width); // mask out removed leaves
+	j1 = irbit(row_tmp, 0, notu); // find first leave on 0-side of branch i
+	j = j1-1;
+	et(column_tmp, columns[j], column_mask, height); // mask out removed rows
+	while ( (j1 = irbit(row_tmp, j1, notu)) != 0) {// for all other leaves on 0-side of branch i
+	  for (k = 0; k < height; k++) { // check that column k is identical-with-mask to column j1-1
+	    if (column_tmp[k] != (columns[j1-1][k] & column_mask[k])) break;
+	  }
+	  if (k < height) break;
+	}
+      }
+      if (k < height) continue; // not all colummns on one side of the branch were identical-with-mask
+      // we have found a cherry corresponding to row i
+      j = irbit(row_tmp, 0, notu) - 1; // first of the cherry leaves
+      bit0(column_mask, i+1); // remove row (=tree internal branch) i from list of remaining rows
+      restbranches--; // one branch less to process
+      // build growing tree string containing leave j
+      newtree = (char*)malloc(strlen(treeparts[j]) + 2);
+      sprintf(newtree, "(%s", treeparts[j]);
+      j1 = j+1;
+      while ( (j1 = irbit(row_tmp, j1, notu)) != 0) { // add names of all found leaves
+	k = j1-1;
+	l = strlen(newtree) + strlen(treeparts[k]) + 2;
+	newtree = (char*)realloc(newtree, l+1);
+	strcat(newtree, ",");
+	strcat(newtree, treeparts[k]);
+	free(treeparts[k]);
+	treeparts[k] = NULL;
+      }
+      strcat(newtree, ")");
+      free(treeparts[j]);
+      treeparts[j] = newtree;
+      for (k = 0; k < width; k++) { // remove found leaves from row_mask 
+	row_mask[k] &= (~row_tmp[k]);
+      }
+      bit1(row_mask, j+1); // except leave j
+    }
+  } // end of loop while branches remain
+  l = 0; // build complete Newick string of tree after all branches have been processed
+  for (i = 0; i < notu; i++) { // 3 or more non-NULL treeparts[i] remain
+    if (treeparts[i]) l += strlen(treeparts[i]) + 1;
+  }
+  newtree = (char*)malloc(l + 3);
+  p = newtree;
+  for (i = 0; i < notu; i++) {
+    if (!treeparts[i]) continue;
+    sprintf(p, ",%s", treeparts[i]);
+    p += strlen(p);
+    free(treeparts[i]);
+    treeparts[i] = NULL;
+    }
+  *newtree = '(';
+  strcpy(p, ");"); // final Newick string is complete
+  free(column_mask); // free memory
+  free(column_tmp);
+  free(row_mask);
+  free(row_tmp);
+  for (i = 0; i < notu; i++) free(columns[i]);
+  free(columns);
+  free(treeparts);
+  return newtree;
+}
+
+
+void init_consensus_calculation(int n)
+{
+  notu = n;
+  w_bits = (notu-1) / lmot + 1;
+  modulo = 997;
+  hashtable = (branche **)calloc(modulo, sizeof(branche *));
+  candidate_bits = (int *)calloc(w_bits, sizeof(int));
+}
+
+static int recodeleaves_consensus(struct noeud *node, struct noeud *parent, char **seqnames)
+//returns != 0 iff error
+{
+  int i;
+  
+  if (node == NULL) return 0;
+  if (is_leave(node)) {
+    for (i=0; i < notu; i++) {
+      if (strcmp(node->nom, seqnames[i])==0) {
+	node->rank = i;
+	break;
+      }
+    }
+    if (i>= notu) return 1;
+  }
+  if (node->v1 != parent) recodeleaves_consensus(node->v1, node, seqnames); 
+  if (node->v2 != parent) recodeleaves_consensus(node->v2, node, seqnames); 
+  if (node->v3 != parent) recodeleaves_consensus(node->v3, node, seqnames); 
+  return 0;
+}
+
+branche *find_branch_consensus(int *bits)
+{
+  int h;
+  branche *br;
+  
+  h = hashvalue(bits, modulo, notu);
+  br = hashtable[h];
+  while (br != NULL) {
+    if(memcmp(br->bits, bits, w_bits * sizeof(int) ) == 0) return br;
+    br = br->next_h;
+  }
+  br = (branche*)calloc(1, sizeof(branche));;
+  br->bits = (int*)malloc(w_bits*sizeof(int));
+  memcpy(br->bits, bits, w_bits*sizeof(int));
+  br->count = 0;
+  br->next_h = NULL;
+  add_hash(br);
+  return br;
+}
+
+static void process_branch_consensus(struct noeud *cote1, struct noeud *cote2)
+{ 
+  branche *br;
+  
+  /* eliminer branches terminales */
+  if (is_leave(cote1) || is_leave(cote2) ) return;
+  
+  memset(candidate_bits, 0, w_bits * sizeof(int));
+  
+  set_leaves(cote1, cote2, candidate_bits);
+  if (! testbit(candidate_bits, 1) ) {
+    int width, word = 1;
+    non(candidate_bits, candidate_bits, w_bits);
+    /* eliminer bits a 1 terminaux */
+    width = notu % lmot;
+    if (width > 1) word = (1 << width) - 1;
+    if (width > 0) candidate_bits[w_bits - 1] &= word;
+  }
+  br = find_branch_consensus(candidate_bits);
+  br->count += 1;
+}
+
+static void parcourir_branches_consensus(struct noeud *centre, struct noeud *origine)
+/* parcourir recursivement toutes les branches de l'arbre sans racine
+ a partir de centre et dans la direction opposee a son voisin origine
+ */
+{
+  if(centre==NULL) return;
+  if(centre->v1!=origine) {
+    if (centre->l1) process_branch_consensus(centre, centre->v1);
+    parcourir_branches_consensus(centre->v1, centre);
+  }
+  if(centre->v2!=origine) {
+    if (centre->l2) process_branch_consensus(centre, centre->v2);
+    parcourir_branches_consensus(centre->v2, centre);
+  }
+  if(centre->v3!=origine) {
+    if (centre->l3) process_branch_consensus(centre, centre->v3);
+    parcourir_branches_consensus(centre->v3, centre);
+  }
+}
+
+
+int process_one_consensus_item(char *one_tree, char **seqnames)
+{
+  struct noeud *eachroot;
+  char *message;
+  struct noeud  **eachtabtax;
+  branche  *eachbranches;
+  
+  message = preptree(one_tree, NULL, &eachroot, &eachtabtax, &eachbranches);
+  if (message != NULL) return 0;
+  if( recodeleaves_consensus(eachroot, NULL, seqnames) ) return 0;
+  parcourir_branches_consensus(eachroot, NULL);
+  free_arbre(eachroot, NULL);
+  free(eachtabtax); 
+  free_branches(eachbranches);
+  return 1;
+}
+
+
+int after_consensus_items(float threshold, int item_count, int ***prows)
+{
+  branche *br, *br2;
+  int i, j = 0, br_count = 0;
+  if (threshold > 0.999) threshold = 0.999;
+  else if (threshold < 0.501) threshold = 0.501;
+  for (i = 0; i < modulo; i++) {
+    br = hashtable[i];
+    while (br) {
+      if (br->count/item_count >= threshold) br_count++;
+      else free(br->bits);
+      br = br->next_h;
+    }
+  }
+  int **rows = (int**)malloc(br_count * sizeof(int*));
+  for (i = 0; i < modulo; i++) {
+    br = hashtable[i];
+    while (br) {
+      if (br->count/item_count >= threshold) rows[j++] = br->bits;
+      br2 = br->next_h;
+      free(br);
+      br = br2;
+    }
+  }
+  *prows = rows;
+  free(hashtable);
+  free(candidate_bits);
+  return br_count;
 }
