@@ -964,11 +964,15 @@ int clustalopt = ALIGN_OPTIONS + 1;
 
 int reponse =  ((Fl_Menu_*)ob)->mvalue() - view->menu_align - clustalopt;
 if(reponse >= 0 && reponse <  view->count_msa_algos) { 
-	view->alignment_algorithm = reponse;  
+	view->alignment_algorithm = reponse;
 	opts = get_algo_opts(view->alignment_algorithm, NULL);
 	set_algo_option_item(opts, (Fl_Menu_Item*)view->menu_align, clustalopt + MAX_MSA_ALGOS, FALSE);
 	if(view->alignment_algorithm >= 2) ((Fl_Menu_Item *)view->menu_align + clustalopt + MAX_MSA_ALGOS + 3)->activate();
 	else ((Fl_Menu_Item *)view->menu_align + clustalopt + MAX_MSA_ALGOS + 3)->deactivate();
+  char tmp[5];
+  sprintf(tmp, "%d", reponse);
+  set_res_value("alignment", tmp);
+  save_resources();
 	}
 }
 
@@ -1540,6 +1544,18 @@ int command_line_align(int argc, char **argv)
       if (l > DNAview->seq_length) DNAview->seq_length = l;
     }
     view = DNAview;
+    int maxl = 3*((view->seq_length+2)/3); // desired alignment length as multiple of 3
+    for(i = 0; i < view->tot_seqs; i++) { // extend all seqs to maxl length with gaps
+      int l = view->each_length[i];
+      if (l == maxl) continue;
+      p = (char *)realloc(view->sequence[i], maxl + 1);
+      if (p == NULL) continue;
+      view->sequence[i] = p;
+      p += l;
+      while(l++ < maxl) *(p++) = '-';
+      view->each_length[i] = maxl;
+      *p = 0;
+      }
   }
   
   char *outfile = process_output_options(argc, argv, out_format, std_output);
