@@ -80,7 +80,6 @@ void Bionj(matrix *mat)
   while(mat->r > 3)
     {
       x = y =  0;
-      vxy   = .0;
       score = .0;
       Compute_Sx(mat);
       Best_Pair(mat,&x,&y,&score);
@@ -103,7 +102,6 @@ void Finish(matrix *mat)
   node *nx,*ny,*nz,*new;
   int i;
 
-  dxy = dxz = dyz = -1.;
   x = y = z = -1;
 
   For(i,mat->n_otu)
@@ -159,7 +157,6 @@ void Update_Mat(matrix *mat, int x, int y, phydbl lx, phydbl ly, phydbl vxy, phy
   int i;
   int a,b;
   
-  a = b = -1;
   For(i,mat->n_otu)
     {
       if((mat->on_off[i]) && (i != x) && (i != y))
@@ -431,7 +428,6 @@ phydbl Q_Agglo(matrix *mat, int x, int y)
 {
   phydbl Qxy;
 
-  Qxy = .0;
   Qxy=(mat->r-2.)*Dist(mat,x,y)-Sum_S(mat,x)-Sum_S(mat,y); 
   return(Qxy);                       
 }
@@ -472,7 +468,6 @@ int Bionj_Br_Length_Post(node *a, node *d, matrix *mat)
       x = Bionj_Br_Length_Post(d,d->v[d_v1],mat);
       y = Bionj_Br_Length_Post(d,d->v[d_v2],mat);
 
-      vxy = .0;
       Compute_Sx(mat);
       vxy=Variance(mat,(x),(y));
       lx=Br_Length(mat,(x),(y));    
