@@ -77,41 +77,41 @@ void   load_tree(long treei);
 /* function prototypes */
 
 
-Char infilename[FNMLNGTH], outfilename[FNMLNGTH], intreename[FNMLNGTH], *outtreename,
+static Char infilename[FNMLNGTH], outfilename[FNMLNGTH], intreename[FNMLNGTH], *outtreename,
      weightfilename[FNMLNGTH];
 char basechar[32]="ACMGRSVTWYHKDBNO???????????????";
-node *root;
-long chars, col, msets, ith, njumble, jumb, maxtrees;
+static node *root;
+static long chars, col, msets, ith, njumble, jumb, maxtrees;
 /*   chars = number of sites in actual sequences */
-long inseed, inseed0;
-double threshold;
-boolean jumble, usertree, thresh, weights, thorough, rearrfirst,
+static long inseed, inseed0;
+static double threshold;
+static boolean jumble, usertree, thresh, weights, thorough, rearrfirst,
           trout, progress, stepbox, ancseq, mulsets, justwts, firstset, mulf,
           multf;
 steptr oldweight;
-longer seed;
-pointarray treenode;            /* pointers to all nodes in tree */
-long *enterorder;
+static longer seed;
+static pointarray treenode;            /* pointers to all nodes in tree */
+static long *enterorder;
 long *zeros;
 
 /* local variables for Pascal maketree, propagated globally for C version: */
 
-long minwhich;
+static long minwhich;
 static double like, minsteps, bestyet, bestlike, bstlike2;
-boolean lastrearr, recompute;
-double nsteps[maxuser];
-long **fsteps;
-node *there, *oldnufork;
-long *place;
-bestelm *bestrees;
-long *threshwt;
+static boolean lastrearr, recompute;
+static double nsteps[maxuser];
+static long **fsteps;
+static node *there, *oldnufork;
+static long *place;
+static bestelm *bestrees;
+static long *threshwt;
 baseptr nothing;
-gbases *garbage;
-node *temp, *temp1, *temp2, *tempsum, *temprm, *tempadd, *tempf, *tmp, *tmp1,
+static gbases *garbage;
+static node *temp, *temp1, *temp2, *tempsum, *temprm, *tempadd, *tempf, *tmp, *tmp1,
        *tmp2, *tmp3, *tmprm, *tmpadd;
-boolean *names;
+static boolean *names;
 node *grbg;
-char *progname;
+static char *progname;
 
 
 static void getoptions(int arg_maxtrees, dnapars_S_option s_option)
