@@ -143,7 +143,7 @@ void init(int argc, char** argv)
   /* Set default terminal characteristics */
   ibmpc = IBMCRT;
   ansi = ANSICRT;
-  javarun = false;
+  //javarun = false;
 
   /* Clear the screen */
   cleerhome();
