@@ -342,7 +342,7 @@ MALLOCRETURN    *mymalloc(long);
 /* Lower-triangular format. */
 #define MAT_LOWERTRI    (MAT_LOWER | MAT_MACHINE)
 
-boolean javarun;
+//boolean javarun;
 
 typedef long *steptr;
 typedef long longer[6];
@@ -363,7 +363,7 @@ extern long spp, words, bits;
 extern boolean ibmpc, ansi, tranvsp;
 //extern naym *nayme;                     /* names of species */
 extern char* *nayme;                     /* names of species */
-boolean firstplotblock; // for debugging BMP output
+//boolean firstplotblock; // for debugging BMP output
 
 #define ebcdic          EBCDIC
 
