@@ -104,39 +104,39 @@ extern void awake_from_C(void);
 
 
 
-Char infilename[FNMLNGTH], outfilename[FNMLNGTH], intreename[FNMLNGTH], *outtreename, weightfilename[FNMLNGTH];
-node *root;
-long chars, col, msets, ith, njumble, jumb;
+static Char infilename[FNMLNGTH], outfilename[FNMLNGTH], intreename[FNMLNGTH], *outtreename, weightfilename[FNMLNGTH];
+static node *root;
+static long chars, col, msets, ith, njumble, jumb;
 /*   chars = number of sites in actual sequences */
-long inseed, inseed0;
-boolean jumble, usertree, weights, thresh, trout, progress, stepbox,
+static long inseed, inseed0;
+static boolean jumble, usertree, weights, thresh, trout, progress, stepbox,
     justwts, ancseq, mulsets, firstset;
 codetype whichcode;
 long fullset, fulldel;
-pointarray treenode;   /* pointers to all nodes in tree */
-double threshold;
-steptr threshwt;
-longer seed;
-long *enterorder;
+static pointarray treenode;   /* pointers to all nodes in tree */
+static double threshold;
+static steptr threshwt;
+static longer seed;
+static long *enterorder;
 sitearray translate[(long)quest - (long)ala + 1];
 aas trans[4][4][4];
-long **fsteps;
-bestelm *bestrees;
+static long **fsteps;
+static bestelm *bestrees;
 boolean dummy;
-gseq *garbage;
-node *temp, *temp1;
+static gseq *garbage;
+static node *temp, *temp1;
 Char ch;
 aas tmpa;
-char *progname;
+static char *progname;
 
 /* Local variables for maketree, propagated globally for c version: */
-long minwhich;
+static long minwhich;
 static double like, bestyet, bestlike, minsteps, bstlike2;
-boolean lastrearr, recompute;
-node *there;
-double nsteps[maxuser];
-long *place;
-boolean *names;
+static boolean lastrearr, recompute;
+static node *there;
+static double nsteps[maxuser];
+static long *place;
+static boolean *names;
 
 
 /*void protgnu(gseq **p)
