@@ -377,6 +377,8 @@ raa_current_db->raa_sockfdw = fdopen(raa_snum,"a");
 
 
 extern void raa_MD5String (char *in_string, char out_digest[33]);
+#define default_raa_maxlists  50
+int raa_maxlists = default_raa_maxlists; // can be changed by caller of raa_opendb_pw() before the call
 
 int raa_opendb_pw(raa_db_access *raa_current_db, const char *db_name, void *ptr, char *(*getpasswordf)(void *) )
 /*
@@ -395,7 +397,8 @@ char *reponse, *code, *p, *challenge;
 int codret, totspecs, totkeys, i;
 
 if(raa_current_db == NULL) return nosocket;
- sock_printf(raa_current_db, "acnucopen&db=%s\n", db_name);
+ sock_printf(raa_current_db, "acnucopen&db=%s&maxlists=%d\n", db_name, raa_maxlists);
+ raa_maxlists = default_raa_maxlists; // reset to default in prevision of future raa_opendb_pw() calls
  reponse=read_sock(raa_current_db);
  if(reponse == NULL) return nosocket;
  rep=initreponse();
@@ -506,7 +509,9 @@ if (p != NULL) {
       raa_current_db->readshrt2_data[i]->point = 0;
       raa_current_db->readshrt2_data[i]->next = 0;
     }
-  
+p = val(rep,"version");
+if (p != NULL) { raa_current_db->version_string = p; }
+
 clear_reponse(rep);
 return 0;
 }
@@ -710,7 +715,8 @@ int raa_prep_acnuc_query(raa_db_access *raa_current_db) {
   int codret, i;
   Reponse *rep;
 
-if(raa_current_db == NULL) return -1;
+  if (raa_current_db == NULL) return -1;
+  if (raa_current_db->maxlists) return raa_current_db->maxlists;
   rep = initreponse();
 
   sock_fputs(raa_current_db, "countfreelists\n");
@@ -725,6 +731,7 @@ if(reponse == NULL) return -1;
   reponse=val(rep,"free");
   if(reponse != NULL) {
 	codret = atoi(reponse);
+        raa_current_db->maxlists = codret;
   	free(reponse);
   	}
 annotlines = val(rep, "annotlines");
@@ -736,8 +743,9 @@ if(annotlines != NULL) {
 		raa_current_db->tot_key_annots++;
 		}
 	while((p = strchr(p, '|')) != NULL);
-	raa_current_db->want_key_annots = (unsigned char *)malloc(raa_current_db->tot_key_annots * 
+	raa_current_db->want_key_annots = (unsigned char *)calloc(raa_current_db->tot_key_annots,
 		sizeof(unsigned char));
+        raa_current_db->want_key_annots[0] = TRUE;
 	raa_current_db->key_annots = (char **)malloc(raa_current_db->tot_key_annots * sizeof(char *));
 	raa_current_db->key_annots_min = (char **)malloc(raa_current_db->tot_key_annots * sizeof(char *));
 	p = annotlines;
@@ -3049,15 +3057,15 @@ return raa_current_db->sp_tree[rank]->name;
 }
 
 
-static char *raa_getattributes_both(raa_db_access *raa_current_db, const char *id, int rank,
-	int *prank, int *plength, int *pframe, int *pgc, char **pacc, char **pdesc, char **pspecies, char **pseq)
+char *raa_getattributes_both(raa_db_access *raa_current_db, const char *id, int rank,
+	int *prank, int *plength, int *pframe, int *pgc, char **pacc, char **pdesc, char **pspecies, char **pseq, char **pprot)
 /*
 for a sequence identified by name or acc. no. (id != NULL) or by rank
 returns rank, name, accession, length, frame, acnuc genetic code ID,
 one-line description, species, and full sequence.
 return value: NULL if not found or name (in private memory)
-pacc, pdesc, pspecies and pseq point to private memory upon return
-prank, plength, pframe, pgc, pacc, pdesc, pspecies, pseq can be NULL is no such information is needed
+pacc, pdesc, pspecies, pseq and pprot point to private memory upon return
+prank, plength, pframe, pgc, pacc, pdesc, pspecies, pseq, pprot can be NULL is no such information is needed
 */
 {
 Reponse *rep;
@@ -3065,8 +3073,8 @@ char *p, *reponse;
 int err;
 
 if(raa_current_db == NULL) return NULL;
-if(id != NULL) sock_printf(raa_current_db, "getattributes&id=%s&seq=%c\n", id, pseq == NULL ? 'F' : 'T');
-else sock_printf(raa_current_db, "getattributes&rank=%d&seq=%c\n", rank, pseq == NULL ? 'F' : 'T');
+if(id != NULL) sock_printf(raa_current_db, "getattributes&id=%s&seq=%c&prot=%c\n", id, pseq == NULL ? 'F' : 'T', pprot == NULL ? 'F' : 'T');
+else sock_printf(raa_current_db, "getattributes&rank=%d&seq=%c&prot=%c\n", rank, pseq == NULL ? 'F' : 'T', pprot == NULL ? 'F' : 'T');
 reponse = read_sock(raa_current_db);
 if(reponse == NULL) {
 	return NULL;
@@ -3126,10 +3134,18 @@ if(err == 0) {
 		free(p);
 		*pdesc = raa_current_db->descript;
 		}
-	if(pseq != NULL) {
-		*pseq = read_sock(raa_current_db); 
-		if(*pseq != NULL) {
-			*pseq += 4; /* seq=xxxx */
+	if(pseq != NULL || pprot != NULL) {
+		char *p = read_sock(raa_current_db);
+		char *q = strstr(p, "prot=");
+		if (q && q > p && *(q-1) == '&') *(q-1) = 0;
+		p = strstr(p, "seq=");
+		if (pseq != NULL) {
+			if (p) *pseq = p + 4; /* seq=xxxx */
+			else *pseq = "";
+			}
+		if (pprot != NULL) {
+			if (q) *pprot = q + 5; /* prot=xxxx */
+			else *pprot = "";
 			}
 		}
 	err = 0;
@@ -3142,14 +3158,14 @@ return (err ? NULL : raa_current_db->mnemo);
 char *raa_getattributes(raa_db_access *raa_current_db, const char *id,
 						int *prank, int *plength, int *pframe, int *pgc, char **pacc, char **pdesc, char **pspecies, char **pseq)
 {
-	return raa_getattributes_both(raa_current_db, id, 0, prank, plength, pframe, pgc, pacc, pdesc, pspecies, pseq);
+	return raa_getattributes_both(raa_current_db, id, 0, prank, plength, pframe, pgc, pacc, pdesc, pspecies, pseq, NULL);
 }
 
 
 char *raa_seqrank_attributes(raa_db_access *raa_current_db, int rank,
 							 int *plength, int *pframe, int *pgc, char **pacc, char **pdesc, char **pspecies, char **pseq)
 {
-	return raa_getattributes_both(raa_current_db, NULL, rank, NULL, plength, pframe, pgc, pacc, pdesc, pspecies, pseq);
+	return raa_getattributes_both(raa_current_db, NULL, rank, NULL, plength, pframe, pgc, pacc, pdesc, pspecies, pseq, NULL);
 }
 
 
