@@ -307,7 +307,7 @@ int tree_btos(int** arbre_b, int notu, double* lgbi, double* lgbp, double* bootv
 {
 	
 	noeud   	p1, p2;
-	int           notuv, i, j, k, sommebi, tax1, tax2, n1, n2, n3, cpt1=-1;
+	int           notuv, i, j, k, sommebi, tax1, tax2, n1=0, n2=0, n3=0, cpt1=-1;
 	int           *kill_tax, *kill_bi;
 	double	arg6, arg9;
 	
