@@ -768,8 +768,43 @@ input->position(0);
 return FALSE;
 }
 
+static int *sort_f_transmit;
 
-char calc_site_consensus(int *freqs, int dernier, int threshold, char *residues, char unknown, int total, 
+static int sort_f(const void *v1, const void *v2) {
+  int i1 = *(int*)v1;
+  int i2 = *(int*)v2;
+  return sort_f_transmit[i2] - sort_f_transmit[i1];
+}
+
+char calc_iupac_consensus(int *freqs, float minval) {
+  // order for freqs[1-16]: ACGTUMRWSYKVHDBN
+  // code for nucleotide sets: 4 bits representing A,C,G,T=U
+  // then coded_set[i-1] is the integer value of the set of count freq[i]
+  static int coded_set[16] = {1,2,4,8,8,3,5,9,6,10,12,7,11,13,14,15};
+  static char set_to_iupac[18] = {".ACMGRSVTWYHKDBN"};
+  int sorted_freqs[16];
+  freqs[16] += freqs[0]; // add count of non-IUPAC characters to count of N
+  for (int i = 0; i < 16; i++) sorted_freqs[i] = i+1;
+  sort_f_transmit = freqs;
+  // sort residue counts in decreasing order
+  qsort(sorted_freqs, 16, sizeof(int), sort_f);
+  int cumul = 0;
+  int set = 0;
+  // walk through residue counts in decreasing order until cumulated counts exceeds minval
+  for (int rank = 0; rank < 16; rank++) {
+    int residue = sorted_freqs[rank]; // the next most frequent residue
+    cumul += freqs[residue]; // summed frequencies till here
+    set |= coded_set[residue - 1]; // the set of all counted residues till here
+    // residues of equal frequencies are pooled together
+    if (rank < 15 && freqs[residue] == freqs[sorted_freqs[rank+1]]) continue;
+    if (cumul >= minval ) break;
+  }
+  if (set == 8 && sorted_freqs[0] == 5) return 'U';
+  return set_to_iupac[set];
+}
+
+
+char calc_site_consensus(int *freqs, int dernier, int threshold, char *residues, char unknown, int total,
 						 int protein, int allowgaps, int iupac)
 {
 	char retval;
@@ -784,36 +819,20 @@ char calc_site_consensus(int *freqs, int dernier, int threshold, char *residues,
 			kind = num;
 			}
 		}
-	if(allowgaps && !protein) {
-		num = dernier - 1;//check if '-' has the highest freq
-		if(freqs[num] > maxi) {
-			maxi = freqs[num];
-			kind = num;
+  if (!protein && !iupac) {
+    total -= freqs[16];//DNA: don't count uninformative N's for frequency calculation
+    if(total == 0) return 'N';
+  }
+  float minval = total * (threshold / 100.);
+	if (allowgaps) {
+		num = dernier - 1; // check if '-' has the highest freq
+		if (freqs[num] > maxi) {
+                  return freqs[num] > minval ? '-' : unknown;
 		}
 	}
-	if(!protein) {
-	  total -= freqs[16];//DNA: don't count uninformative N's for frequency calculation
-	  if(total == 0) return 'N';
-	  }
-	float minval = total * (threshold / 100.);
-	if(iupac && !protein ) { // for DNA/RNA with IUPAC codes
-		if( maxi >= minval ) retval = residues[kind - 1];
-		else if(freqs[1] + freqs[2] + freqs[6] >= minval) retval = 'M';//AC
-		else if(freqs[1] + freqs[3] + freqs[7] >= minval) retval = 'R';//AG
-		else if(freqs[1] + freqs[4] + freqs[5] + freqs[8] >= minval) retval = 'W';//AT(U)
-		else if(freqs[2] + freqs[3] + freqs[9] >= minval) retval = 'S';//CG
-		else if(freqs[2] + freqs[4] + freqs[5] + freqs[10] >= minval) retval = 'Y';//CT(U)
-		else if(freqs[3] + freqs[4] + freqs[5] + freqs[11] >= minval) retval = 'K';//GT(U)
-		else if(freqs[1] + freqs[2] + freqs[3] + freqs[6] + 
-				freqs[9] + freqs[7] + freqs[12] >= minval) retval = 'V';//ACG
-		else if(freqs[1] + freqs[2] + freqs[4] + freqs[5] + 
-				freqs[6] + freqs[8] + freqs[10] + freqs[13] >= minval) retval = 'H';//ACT(U)
-		else if(freqs[1] + freqs[3] + freqs[4] + freqs[5] + 
-				freqs[7] + freqs[8] + freqs[11] + freqs[14] >= minval) retval = 'D';//AGT(U)
-		else if(freqs[2] + freqs[3] + freqs[4] + freqs[5] + 
-				freqs[9] + freqs[10] + freqs[11] + freqs[15] >= minval) retval = 'B';//CGT(U)
-		else retval = 'N';
-		}
+	if (iupac && !protein ) { // for DNA/RNA with IUPAC codes
+          retval = calc_iupac_consensus(freqs, minval);
+          }
 	else {
 		if( maxi >= minval )
 			retval = residues[kind - 1];
