@@ -97,22 +97,22 @@ char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int use_o
   NSString *dir = [[NSString alloc] initWithUTF8String:directory];
   NSString *preset = [[NSString alloc] initWithUTF8String:dfault];
   NSString *fname = [preset lastPathComponent];
-  NSRect rectview = {{0, 0}, {500, 65} };
+  NSRect rectview = {{0, 0}, {513, 65} };
   NSView *view = [[[NSView alloc] initWithFrame:rectview] autorelease];
 //blocksize  
-  label(12, 15, 45, 30, "block\nsize:", view);
-  NSRect rectblock = {{50, 20}, {35, 20} };
+  label(5, 28, 75, 15, "block size:", view);
+  NSRect rectblock = {{68, 25}, {35, 20} };
   NSTextField *blockview = [[[NSTextField alloc] initWithFrame:rectblock] autorelease];
   [view addSubview:blockview];
   [blockview setIntValue:printout_block];
 //fontsize
-  label(102, 15, 45, 30, "font\nsize:", view);
-  NSRect rectfont = {{140, 20}, {35, 20} };
+  label(109, 28, 75, 15, "font size:", view);
+  NSRect rectfont = {{165, 25}, {35, 20} };
   NSTextField *fontview = [[[NSTextField alloc] initWithFrame:rectfont] autorelease];
   [view addSubview:fontview];
   [fontview setIntValue:printout_fontsize];
 //color  
-  NSRect pdfrect = {{190, -10}, {80, 70} };
+  NSRect pdfrect = {{215, -10}, {80, 70} };
   NSMatrix *pdfmatrix = [[[NSMatrix alloc] initWithFrame:pdfrect mode:NSRadioModeMatrix 
 						cellClass:[NSButtonCell class]
 					 numberOfRows:3 numberOfColumns:1] autorelease];
@@ -137,7 +137,7 @@ char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int use_o
   if([pdfmatrix selectedRow] != printout_black) [pdfmatrix selectCellAtRow:printout_black column:0];
   [view addSubview:pdfmatrix];
 //paper format  
-  NSRect paperrect = {{280, -10}, {80, 70} };
+  NSRect paperrect = {{305, -10}, {80, 70} };
   NSMatrix *papermatrix = [[[NSMatrix alloc] initWithFrame:paperrect mode:NSRadioModeMatrix 
 						 cellClass:[NSButtonCell class]
 					      numberOfRows:2 numberOfColumns:1] autorelease];
@@ -157,7 +157,7 @@ char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int use_o
   if ([papermatrix selectedRow] != desired_paper_cell) [papermatrix selectCellAtRow:desired_paper_cell column:0];
   [view addSubview:papermatrix];
 // landscape button
-  NSRect landscaperect = {{280, 6}, {80, 20} };
+  NSRect landscaperect = {{305, 6}, {80, 20} };
   NSButton *landscape = [[[NSButton alloc] initWithFrame:landscaperect] autorelease];
   [landscape setButtonType:switch_button_style];
   [landscape setTitle:@"landscape"];
@@ -166,7 +166,7 @@ char *mac_GetOutputFName_Plus(const char *dfault, const char *message, int use_o
   [landscape setEnabled:YES];
   [view addSubview:landscape];
 //variable site button  
-  NSRect variablerect = {{360, 30}, {80, 20} };
+  NSRect variablerect = {{385, 25}, {80, 20} };
   NSButton *variable = [[[NSButton alloc] initWithFrame:variablerect] autorelease];
   [variable setButtonType:switch_button_style];
   [variable setTitle:@"variable sites only"];
@@ -608,140 +608,6 @@ void mac_tmp_dir_name(char *buffer, int l)
 
 #include <FL/Fl_PostScript.H>
 
-class EPS_File_Surface : public Fl_Widget_Surface {
-protected:
-  inline Fl_PostScript_Graphics_Driver *driver() { return (Fl_PostScript_Graphics_Driver*)Fl_Surface_Device::driver(); }
-public:
-  EPS_File_Surface(const char *filename, int width, int height, Fl_Color background = FL_WHITE);
-  ~EPS_File_Surface();
-  int start_eps(int width, int height);
-  virtual int printable_rect(int *w, int *h);
-  FILE *file() { return driver()->output; }
-  virtual void origin(int x, int y);
-  virtual void origin(int *px, int *py);
-  virtual void translate(int x, int y);
-  virtual void untranslate();
-};
-
-EPS_File_Surface::EPS_File_Surface(const char *filename, int width, int height, Fl_Color background) :
-        Fl_Widget_Surface(new Fl_PostScript_Graphics_Driver()) {
-  Fl_PostScript_Graphics_Driver *ps = driver();
-  ps->output = fl_fopen(filename, "w+");
-  if (ps->output) {
-    ps->ps_filename_ = strdup(filename);
-    float s = Fl::screen_scale(0);
-    start_eps(width*s, height*s);
-    if (s != 1) {
-      ps->clocale_printf("GR GR GS %f %f SC GS\n", s, s);
-      ps->scale_x = ps->scale_y = s;
-    }
-    Fl::get_color(background, ps->bg_r, ps->bg_g, ps->bg_b);
-  }
-}
-
-EPS_File_Surface::~EPS_File_Surface() {
-  Fl_PostScript_Graphics_Driver *ps = driver();
-  if(ps->output == NULL) return;
-  fputs("GR\nend %matches begin of FLTK dict\n", ps->output);
-  fputs("restore\n", ps->output);
-  fputs("%%EOF\n", ps->output);
-  ps->reset();
-  fflush(ps->output);
-  if(ferror(ps->output)) {
-    fl_alert ("Error during PostScript data output.");
-  }
-  fclose(ps->output);
-  while (ps->clip_){
-    Fl_PostScript_Graphics_Driver::Clip * c= ps->clip_;
-    ps->clip_= ps->clip_->prev;
-    delete c;
-  }
-}
-
-int EPS_File_Surface::start_eps(int width, int height) {
-  Fl_PostScript_Graphics_Driver *ps = driver();
-  ps->width_ = width;
-  ps->height_ = height;
-  fputs("%!PS-Adobe-3.0 EPSF-3.0\n", file());
-  fputs("%%Creator: (FLTK)\n", file());
-  fprintf(file(),"%%%%BoundingBox: 1 1 %d %d\n", width, height);
-  if (ps->ps_filename_) fprintf(file(),"%%%%Title: (%s)\n", fl_filename_name(ps->ps_filename_));
-  time_t lt = time(NULL);
-  fprintf(file(),"%%%%CreationDate: %s", ctime(&lt)+4);
-  ps->lang_level_= 2;
-  fprintf(file(), "%%%%LanguageLevel: 2\n");
-  fputs("%%Pages: 1\n%%EndComments\n", file());
-  fputs("%%BeginProlog\n", file());
-  fputs("%%EndProlog\n",file());
-  fprintf(file(), "save\n");
-  fputs("/FLTK 20 dict def FLTK begin\n"
-  "/x1 0 def /x2 0 def /y1 0 def /y2 0 def /x 0 def /y 0 def /dx 0 def /dy 0 def\n"
-        "/px 0 def /py 0 def /sx 0 def /sy 0 def /inter 0 def\n"
-        "/pixmap_sx 0 def  /pixmap_sy 0 def /pixmap_w 0 def /pixmap_h 0 def\n", file());
-  // trick to get the prolog
-  long cur_pos = ftell(file());
-  Fl_PostScript_File_Device *tmp = new Fl_PostScript_File_Device();
-  tmp->begin_job(file());
-  tmp->end_job();
-  delete tmp;
-  fseek(file(), cur_pos, SEEK_SET);
-  char line[200];
-  do fgets(line, sizeof(line), file());
-  while(strncmp(line, "%%BeginProlog\n", 14));
-  char *prolog = new char[10000], *p = prolog;
-  while (1) {
-    fgets(line, sizeof(line), file());
-    if (strncmp(line, "/CS { GS } bind def\n", 20) == 0) break;
-    strcpy(p, line);
-    p += strlen(p);
-  }
-  int lprolog = strlen(prolog);
-  fseek(file(), cur_pos, SEEK_SET);
-  fwrite(prolog, 1, lprolog, file());
-  delete[] prolog;
-  // end of trick
-  fputs("/CS { GS } bind def\n", file());
-  fputs("/CR { GR } bind def\n", file());
-  ps->page_policy_ = 1;
-  ps->reset();
-  ps->nPages=0;
-  fprintf(file(), "GS\n");
-  ps->clocale_printf( "%g %g TR\n", (double)0, ps->height_);
-  fprintf(file(), "1 -1 SC\n");
-  ps->line_style(0);
-  fprintf(file(), "GS GS\n");
-  return 0;
-}
-
-int EPS_File_Surface::printable_rect(int *w, int *h) {
-  Fl_PostScript_Graphics_Driver *ps = driver();
-  *w = ps->width_;
-  *h = ps->height_;
-  return 0;
-}
-
-void EPS_File_Surface::origin(int x, int y)
-{
-  x_offset = x;
-  y_offset = y;
-  driver()->clocale_printf("GR GR GS %d %d TR  %f %f SC %d %d TR %f rotate GS\n",
-    0, 0, driver()->scale_x, driver()->scale_y, x, y, 0);
-}
-
-void EPS_File_Surface::origin(int *px, int *py) {
-  Fl_Widget_Surface::origin(px, py);
-}
-
-void EPS_File_Surface::translate(int x, int y)
-{
-  fprintf(file(), "GS %d %d translate GS\n", x, y);
-}
-
-void EPS_File_Surface::untranslate()
-{
-  fprintf(file(), "GR GR\n");
-}
-
 void EPS_cb(Fl_Widget *, void *data) {
   Fl_Native_File_Chooser fnfc;
   fnfc.title("Pick an .eps file");
@@ -750,8 +616,9 @@ void EPS_cb(Fl_Widget *, void *data) {
   if (!fnfc.show() ) {
     Fl_Window *target = Fl::first_window();
     if (target) {
-      EPS_File_Surface p(fnfc.filename(), target->decorated_w(), target->decorated_h());
-      if (p.file()) {
+      FILE *file = fl_fopen(fnfc.filename(), "w");
+      if (file) {
+        Fl_EPS_File_Surface p(target->decorated_w(), target->decorated_h(), file);
         p.draw_decorated_window(target);
       }
     }
