@@ -2,9 +2,6 @@
 #define PDF_OR_PS_H
 
 #include <FL/Fl_Paged_Device.H>
-#if 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION + FL_PATCH_VERSION >= 140
-#include <FL/Fl_Graphics_Driver.H>
-#endif
 
 #if defined(WIN32)
 #include <windows.h>
@@ -12,26 +9,31 @@
 
 #ifdef NO_PDF
 #include <FL/Fl_PostScript.H>
-class Fl_PDF_or_PS_File_Device : public Fl_PostScript_File_Device {
+class PDF_or_PS_File_Device : public Fl_PostScript_File_Device {
   FILE *file;
   char *filename;
 public:
-  Fl_PDF_or_PS_File_Device() { file = NULL; }
+  PDF_or_PS_File_Device() { file = NULL; }
   int begin_document(const char* fixedfilename, enum Fl_Paged_Device::Page_Format format=Fl_Paged_Device::A4,
 		     enum Fl_Paged_Device::Page_Layout layout=Fl_Paged_Device::PORTRAIT);
   int start_job(const char *defaultname, enum Fl_Paged_Device::Page_Format format=Fl_Paged_Device::A4, 
 		enum Fl_Paged_Device::Page_Layout layout=Fl_Paged_Device::PORTRAIT);
-  Fl_Graphics_Driver *driver() {  return Fl_PostScript_File_Device::driver(); }
+  Fl_Graphics_Driver *driver() {  return (Fl_Graphics_Driver*)Fl_PostScript_File_Device::driver(); }
   const char *outfname() {return filename; }
-  ~Fl_PDF_or_PS_File_Device();
+  ~PDF_or_PS_File_Device();
 };
 
 #else // NO_PDF
 
 #include <pdflib.h>
 #include <setjmp.h>
+#if 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION + FL_PATCH_VERSION >= 140
+#  include <FL/Fl_Graphics_Driver.H>
+#else
+#  include <FL/Fl_Device.H>
+#endif
 
-class Fl_PDF_Graphics_Driver : public Fl_Graphics_Driver {
+class PDF_Graphics_Driver : public Fl_Graphics_Driver {
 private:
   int pdf_font;
   const char *encoding;
@@ -39,7 +41,7 @@ private:
   int tr_x, tr_y;
 public:
   PDF *pdf;
-  Fl_PDF_Graphics_Driver();
+  PDF_Graphics_Driver();
   void rect(int x, int y, int w, int h);
   void rectf(int x, int y, int w, int h);
   void line_style(int style, int width, char *dashes=0);
@@ -127,7 +129,7 @@ public:
   const char *outfname() {return filename; }
   ~Fl_PDF_File_Device();
 };
-typedef Fl_PDF_File_Device Fl_PDF_or_PS_File_Device;
+typedef Fl_PDF_File_Device PDF_or_PS_File_Device;
 #endif // NO_PDF
 
 #if defined(__APPLE__)
