@@ -338,9 +338,8 @@ int run_external_prog_in_pseudoterm(char *cmd, const char *dialogfname, const ch
 		w = create_and_run_pseudoterminal(label, &data);
 	}
 	else {//the child
-		if(dialogfname != NULL) {//case of use of dialog file
-			freopen(dialogfname, "r", stdin);
-		}
+                // when dialogfname = NULL, make stdin a tty, useful for kalign
+                freopen( (dialogfname ? dialogfname : slavename), "r", stdin);
 		freopen(slavename, "a", stderr);
 #ifdef sun
 		ioctl(fileno(stderr), I_PUSH, "ptem");
