@@ -308,7 +308,8 @@ void use_key_callback(Fl_Widget *ob, void *data)
 			if(strncmp(name, "04", 2) != 0) continue;
 			if(strcmp(name, "04ID") == 0) continue;
 			if(strcmp(name, "04LOCUS") == 0) continue;
-			raa_fields->key_choice->add(name + 2, 0, NULL, (void *)num);
+			int item_rank = raa_fields->key_choice->add(name + 2, 0, NULL, NULL);
+      ((Fl_Menu_Item*)(raa_fields->key_choice->menu() + item_rank))->argument(num);
 			}
 		raa_fields->key_choice->value(0);
 		raa_fields->key_choice->activate();
