@@ -2,11 +2,16 @@
 #include <FL/Fl_Round_Button.H>
 #include <FL/Fl_Check_Button.H>
 #include <ctype.h>
+#if 10000*FL_MAJOR_VERSION + 100*FL_MINOR_VERSION + FL_PATCH_VERSION >= 10305
+#include <FL/platform.H>
+#else
+#include <FL/x.H>
+#endif
 #ifdef WIN32
 #include <wchar.h>
-extern "C" {
+/*extern "C" {
   int _wsystem(const wchar_t *command );
-}
+}*/
 #endif
 
 
@@ -244,12 +249,15 @@ int create_gblocks_mask(SEA_VIEW *view, region *maregion, int no_gui=false, int
   list_segments *segment, *previous;
   void (*alert)(const char*,...) = (no_gui ? Fl::fatal : fl_alert);
   
-  q = get_full_path(
-		    "Gblocks"
 #ifdef WIN32
-		    ".exe"
+#define GBLOCKS_NAME "Gblocks.exe"
+#elif defined(__APPLE__)
+  const char  *GBLOCKS_NAME = (fl_mac_os_version >= 101400 ? "Gblocks_x86_64" : "Gblocks_ppc_i386");
+#else
+#define GBLOCKS_NAME "Gblocks"
 #endif
-		    );
+  q = get_full_path(GBLOCKS_NAME);
+  
   if (!q) {
     alert("Program Gblocks not found."
 #if !(defined(WIN32) || defined(__APPLE__))
