@@ -5,8 +5,9 @@
 #include <string.h>
 #include <limits.h>
 #include <FL/Fl.H>
-#if 100*FL_MAJOR_VERSION + FL_MINOR_VERSION < 103
-#error Seaview requires FLTK version 1.3.0 or higher
+#if 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION + FL_PATCH_VERSION < 134
+// because of Fl_Graphics_Driver::draw_scaled() introduced 1.3.4 used by Fl_SVG_Image
+#error Seaview requires FLTK version 1.3.4 or higher
 #endif
 #include <FL/Fl_Window.H>
 #include <FL/Fl_Menu_Item.H>
@@ -271,7 +272,7 @@ typedef struct _props_menu_parts {
 	int usingcodoncolors;
 	} props_menu_parts;
 
-
+extern void update_treerecs_prog_path(const char* str);
 extern void out_of_memory(void);
 extern "C" void majuscules(char *s);
 extern void init_dna_scroller(SEA_VIEW *view, int totseqs, 
