@@ -7,14 +7,14 @@
 #include "pdf_or_ps.h"
 #endif
 
-class Fl_SVG_Graphics_Driver : public Fl_Graphics_Driver {
+class SVG_Graphics_Driver : public Fl_Graphics_Driver {
   FILE *out_;
   int width_;
   const char *linecap_;
   uchar red_, green_, blue_;
 public:
-  Fl_SVG_Graphics_Driver(FILE*);
-  ~Fl_SVG_Graphics_Driver();
+  SVG_Graphics_Driver(FILE*);
+  ~SVG_Graphics_Driver();
   FILE* file() {return out_;}
 protected:
   const char *family_;
@@ -78,27 +78,27 @@ protected:
 #endif
 };
 
-class Fl_SVG_File_Surface : public Fl_Surface_Device {
+class SVG_File_Surface : public Fl_Surface_Device {
   int width_, height_;
 public:
   static const char *class_id;
   const char *class_name() {return class_id;};
-  Fl_SVG_File_Surface(int, int, FILE*, bool use_pdf_width = false);
+  SVG_File_Surface(int, int, FILE*, bool use_pdf_width = false);
   void end();
   int width() { return width_; }
   int height() { return height_; }
-  ~Fl_SVG_File_Surface();
+  ~SVG_File_Surface();
 };
 
 #ifndef NO_PDF
-/* Fl_SVG_PDF_width_Graphics_Driver uses a PDF graphics driver only to compute string widths and heights,
+/* SVG_PDF_width_Graphics_Driver uses a PDF graphics driver only to compute string widths and heights,
  to allow creation of SVG data without calling fl_open_display().
  */
-class Fl_SVG_PDF_width_Graphics_Driver : public Fl_SVG_Graphics_Driver {
-  Fl_PDF_Graphics_Driver *pdf_driver;
+class SVG_PDF_width_Graphics_Driver : public SVG_Graphics_Driver {
+  PDF_Graphics_Driver *pdf_driver;
 public:
-  Fl_SVG_PDF_width_Graphics_Driver(FILE *f);
-  ~Fl_SVG_PDF_width_Graphics_Driver();
+  SVG_PDF_width_Graphics_Driver(FILE *f);
+  ~SVG_PDF_width_Graphics_Driver();
   int descent();
   int height();
   double width(const char* str, int l);
