@@ -4,6 +4,9 @@
 
 #include <FL/fl_utf8.h>
 
+#if __APPLE_CC__
+#include <xlocale.h>
+#endif
 #include <iostream>
 #include <fstream>
 #include <cstring>
