@@ -1,4 +1,6 @@
-#ifndef WIN32
+#ifdef WIN32
+#include <windows.h>
+#else
 #include <sys/times.h>
 #endif
 #include "seaview.h"
@@ -776,33 +778,36 @@ void phyml_dialog(SEA_VIEW *view)
 	static int first = TRUE;
 	if(first) {
 		char *p, *q;
+#if defined(__APPLE__)
+#  ifdef __ppc__
+          p = (char*)"phyml_3.0_universal";
+#  else
+          p = (char*)(fl_mac_os_version < 100800 ? "phyml_3.0_universal" : "PhyML-3.1_macOS-MountainLion");
+#  endif // __ppc__
+          if ((q = get_full_path(p)) == NULL) {
+            fl_message("Warning: PhyML executable not found. Please, download the seaview macOS application again.");
+            return;
+          }
+#else
 		p = get_res_value("phyml",
-#ifdef WIN32
+#  ifdef WIN32
 					"PhyML-3.1_win32.exe"
-#elif defined(__APPLE__)
-#ifdef __ppc__
-				  "phyml_3.0_universal"
-#else
-				  "PhyML-3.1_macOS-MountainLion"
-#endif
-#elif defined(sparc)
+#  elif defined(sparc)
 						  "phyml_3.0_sparc"
-#else
-#ifndef PHYMLNAME
-#ifdef __i386__
-#define PHYMLNAME "PhyML-3.1_linux32"
-#else
-#define PHYMLNAME "PhyML-3.1_linux64"
-#endif
-#endif
+#  else
+#    ifndef PHYMLNAME
+#      ifdef __i386__
+#        define PHYMLNAME "PhyML-3.1_linux32"
+#      else
+#        define PHYMLNAME "PhyML-3.1_linux64"
+#      endif // __i386__
+#    endif // PHYMLNAME
 					PHYMLNAME
-#endif
+#  endif // WIN32
 		);
-#ifdef __APPLE__
-	  if (fl_mac_os_version < 100800) p = (char*)"phyml_3.0_universal";
-#elif defined(__linux__)
+#if defined(__linux__)
 	  if ((q = get_full_path(p)) == NULL) p = (char*)"phyml";
-#endif
+#endif // __linux__
 		if ((q = get_full_path(p)) == NULL) {
 			int rep = fl_choice("Seaview does not find PhyML under the name %s.\n"
 					  "Is PhyML available on your computer ?", "No", "Available", NULL, p);
@@ -815,6 +820,7 @@ void phyml_dialog(SEA_VIEW *view)
 			set_res_value("phyml", q);
 			save_resources();
 			}
+#endif // __APPLE__
 		first = FALSE;
 		phyml_path = (char *)malloc(strlen(q) + 3);
 		sprintf(phyml_path, "\"%s\"", q);
@@ -2832,6 +2838,7 @@ void command_line_phylogeny(int argc, char **argv)
 				replicates, jumbles, 10000, usertreerank, NULL, s_option, &progname, 1, true, 0, Fl::fatal);
     if (tree && (p = strchr(tree, ';')) != NULL) *(p+1) = 0; // tree string can contain several trees, keep first only
   }
+
   if (tree) {
     char *outfname = argname(argc, argv, "-o");
     FILE *out = (strcmp(outfname, "-") != 0 ? fopen(outfname, "w") : stdout);
