@@ -443,11 +443,11 @@ void print_unrooted(FD_unrooted *fd_unrooted, const char *name, bool to_ps_file,
   old_x = fd_unrooted->x_offset;
   old_y = fd_unrooted->y_offset;
   if (to_ps_file) {
-    myprinter = (Fl_Printer*)new Fl_PDF_or_PS_File_Device();
+    myprinter = (Fl_Printer*)new PDF_or_PS_File_Device();
     if (directname) 
-      error = ((Fl_PDF_or_PS_File_Device*)myprinter)->begin_document(directname, printout_pageformat, printout_layout);
+      error = ((PDF_or_PS_File_Device*)myprinter)->begin_document(directname, printout_pageformat, printout_layout);
     else
-      error = ((Fl_PDF_or_PS_File_Device*)myprinter)->start_job(name, printout_pageformat, printout_layout) ;
+      error = ((PDF_or_PS_File_Device*)myprinter)->start_job(name, printout_pageformat, printout_layout) ;
     if (error) return;
     }
   else {
@@ -460,7 +460,7 @@ void print_unrooted(FD_unrooted *fd_unrooted, const char *name, bool to_ps_file,
   if (to_ps_file) ((Fl_PDF_File_Device*)myprinter)->surface_try(&jbuf);
   if ( (!to_ps_file) || setjmp(*jbuf) == 0) { // replaces PDF_TRY
 #endif    
-    if (to_ps_file) ((Fl_PDF_or_PS_File_Device*)myprinter)->start_page();
+    if (to_ps_file) ((PDF_or_PS_File_Device*)myprinter)->start_page();
     else myprinter->start_page();
     fd_unrooted->previous_w = fd_unrooted->previous_h = 0;
     myprinter->printable_rect( &fd_unrooted->w, &fd_unrooted->h);
