@@ -1697,8 +1697,8 @@ int printout(SEA_VIEW *view, const char *filename,
   }
   widnames += 2;
   if (use_pdf) {
-    surface = new Fl_PDF_or_PS_File_Device();
-    if (((Fl_PDF_or_PS_File_Device*)surface)->begin_document(filename, pageformat, layout)) {
+    surface = new PDF_or_PS_File_Device();
+    if (((PDF_or_PS_File_Device*)surface)->begin_document(filename, pageformat, layout)) {
       delete surface;
       return 0;
     }
@@ -1707,7 +1707,7 @@ int printout(SEA_VIEW *view, const char *filename,
     FILE *out = fl_fopen(filename, "w");
     if (out == NULL) exit(1);
 #ifndef NO_PDF
-    Fl_SVG_PDF_width_Graphics_Driver *pdf_d = new Fl_SVG_PDF_width_Graphics_Driver(NULL);
+    SVG_PDF_width_Graphics_Driver *pdf_d = new SVG_PDF_width_Graphics_Driver(NULL);
     pdf_d->font(FL_COURIER, fontsize);
     char_width = pdf_d->width("X", 1);
     delete pdf_d;
@@ -1721,7 +1721,7 @@ int printout(SEA_VIEW *view, const char *filename,
     res_per_line = fin * block_size;
     int nl = (max_seq_length + res_per_line - 1) /res_per_line;
     int totl = nl * (view->tot_seqs + 2) + 2;
-    surface = new Fl_SVG_File_Surface(svg_width, totl * fontsize, out, true);
+    surface = new SVG_File_Surface(svg_width, totl * fontsize, out, true);
     surface->set_current();
     fl_color(210,210,210); // draw grey background
     fl_rectf(0,0,svg_width, totl * fontsize);
@@ -1732,16 +1732,16 @@ int printout(SEA_VIEW *view, const char *filename,
   }
 #ifndef NO_PDF
   jmp_buf* jbuf;
-  if (use_pdf) ((Fl_PDF_or_PS_File_Device*)surface)->surface_try(&jbuf);
+  if (use_pdf) ((PDF_or_PS_File_Device*)surface)->surface_try(&jbuf);
   if ( (!use_pdf) || (setjmp(*jbuf) == 0)) {
 #endif
     if (use_pdf) {
       surface->driver()->font(FL_COURIER, fontsize);
       char_width = fl_width("X");
       int pwidth, pheight;
-      ((Fl_PDF_or_PS_File_Device*)surface)->printable_rect(&pwidth, &pheight);
+      ((PDF_or_PS_File_Device*)surface)->printable_rect(&pwidth, &pheight);
       int l, r, t, b;
-      ((Fl_PDF_or_PS_File_Device*)surface)->margins(&l, &t, &r, &b);
+      ((PDF_or_PS_File_Device*)surface)->margins(&l, &t, &r, &b);
       margin -= l;
       char_per_line = (int)((pwidth - 2*margin) / char_width + 0.5);
       lines_per_page = (int)((pheight - 2*margin) / fontsize + 0.5);
@@ -1760,8 +1760,8 @@ int printout(SEA_VIEW *view, const char *filename,
     time(&heure);
     sprintf(oneline,"Alignment: %s", view->masename == NULL ? unnamed : PREPARE_LABEL(view->masename) );
     if (use_pdf) {
-      ((Fl_PDF_or_PS_File_Device*)surface)->start_page();
-      ((Fl_PDF_or_PS_File_Device*)surface)->origin(0, fontsize);
+      ((PDF_or_PS_File_Device*)surface)->start_page();
+      ((PDF_or_PS_File_Device*)surface)->origin(0, fontsize);
       fl_draw(oneline, margin, top_margin); 
     }
     else if(!use_svg) {fputs(oneline, textfile); fputs("\n", textfile);}
@@ -1827,9 +1827,9 @@ int printout(SEA_VIEW *view, const char *filename,
 	nl = calc_vary_lines(vary_pos,  k);
       }
       if( use_pdf && (!firstpage) && (curr_lines + view->tot_seqs + nl > lines_per_page)) {
-	((Fl_PDF_or_PS_File_Device*)surface)->end_page();
-	((Fl_PDF_or_PS_File_Device*)surface)->start_page();
-	((Fl_PDF_or_PS_File_Device*)surface)->origin(0, fontsize);
+	((PDF_or_PS_File_Device*)surface)->end_page();
+	((PDF_or_PS_File_Device*)surface)->start_page();
+	((PDF_or_PS_File_Device*)surface)->origin(0, fontsize);
 	surface->driver()->font(FL_COURIER, fontsize);
 	curr_lines = 0;
       }
@@ -1898,9 +1898,9 @@ int printout(SEA_VIEW *view, const char *filename,
 	oneline[k] = 0;
 	if(!view->allow_lower) majuscules(oneline + widnames);
 	if(use_pdf && (curr_lines >= lines_per_page)) {
-	  ((Fl_PDF_or_PS_File_Device*)surface)->end_page();
-	  ((Fl_PDF_or_PS_File_Device*)surface)->start_page();
-	  ((Fl_PDF_or_PS_File_Device*)surface)->origin(0, fontsize);
+	  ((PDF_or_PS_File_Device*)surface)->end_page();
+	  ((PDF_or_PS_File_Device*)surface)->start_page();
+	  ((PDF_or_PS_File_Device*)surface)->origin(0, fontsize);
 	  surface->driver()->font(FL_COURIER, fontsize);
 	  curr_lines = 0;
 	}
@@ -1929,20 +1929,20 @@ int printout(SEA_VIEW *view, const char *filename,
       if( ! vary_only ) current += res_per_line;
     }
     if(use_pdf) {
-      ((Fl_PDF_or_PS_File_Device*)surface)->end_page();
-      ((Fl_PDF_or_PS_File_Device*)surface)->end_job();
+      ((PDF_or_PS_File_Device*)surface)->end_page();
+      ((PDF_or_PS_File_Device*)surface)->end_job();
     }
     else if(use_svg) {
       fl_color(FL_GRAY);
       fl_line_style(0, 3);
-      fl_rect(1,1, ((Fl_SVG_File_Surface*)surface)->width()-2, ((Fl_SVG_File_Surface*)surface)->height()-2);
-      ((Fl_SVG_File_Surface*)surface)->end();
+      fl_rect(1,1, ((SVG_File_Surface*)surface)->width()-2, ((SVG_File_Surface*)surface)->height()-2);
+      ((SVG_File_Surface*)surface)->end();
       }
     else fclose(textfile);
 #ifndef NO_PDF
   } /* end of PDF_TRY */
-  if (use_pdf && ((Fl_PDF_or_PS_File_Device*)surface)->surface_catch()) {
-    ((Fl_PDF_or_PS_File_Device*)surface)->error_catch();
+  if (use_pdf && ((PDF_or_PS_File_Device*)surface)->surface_catch()) {
+    ((PDF_or_PS_File_Device*)surface)->error_catch();
   }
 #endif
   if (use_pdf || use_svg) delete surface;
