@@ -14,7 +14,8 @@ extern "C" {
 	char codaa(char *codon, int code);
 	int get_acnuc_gc_number(int ncbi_gc);
 	int get_ncbi_gc_number(int ncbi_gc);
-	char *get_code_descr(int code);
+        char *get_code_descr(int code);
+	char *get_code_target(int code);
 	}
 extern int totcodes;
 extern void set_and_show_new_cursor_seq(SEA_VIEW *view, int new_pos);
@@ -191,7 +192,7 @@ char *back_translate_with_gaps(char *prot, char *dna)
 		}
 	*pd = 0;
 	while(memcmp(dna, "---", 3) == 0) dna += 3;
-	if (*dna != 0) {//if a partial codon remains at end
+	if (*dna != 0 && *dna != '-') {//if a partial codon remains at end
 	  while (*(pd-1) == '-') pd--;
 	  ld = pd - newdna;
 	  q = dna + strlen(dna);
@@ -253,27 +254,21 @@ void set_ncbi_genetic_code(SEA_VIEW *view)
 int gc = 1, num;
 char line[170];
 int status;
-static char codencbinames[19][60] = { "Standard", "Yeast mt", "Vertebrate mt",
-	"Mold+Protozoan+Coelentarate mt, Mycoplasma Spiroplasma", "Invertebrate mt", "Alternative Yeast Nuclear", 
-	"Ciliate+Dasycladacean+Hexamita Nuclear", "Euplotid Nuclear", "Echinoderm+Flatworm mt",
-	"Ascidian mt", "Alternative Flatworm mt", "Blepharisma Macronuclear", 
-	"Bacterial and Plant Plastid", "Chlorophycean mt", "Trematode mt", 
-	"Scenedesmus obliquus mt", "Thraustochytrium mt", "Pterobranchia mt", "Candidate Division SR1"};
 
 if(view->comments == NULL) view->comments = (char **)calloc(view->tot_seqs, sizeof(char *));
 if(view->comments == NULL) return;
-Fl_Window *win = new Fl_Window(750,390);
+Fl_Window *win = new Fl_Window(850,400);
 win->label("Genetic code selection");
 for(num = 0; num < view->tot_seqs; num++)
 		if(view->sel_seqs[num]) break;
 gc = get_ncbi_gc_from_comment(view->comments[num]);
-Fl_Hold_Browser *obj = new Fl_Hold_Browser(5, 25, 740, 340);
+Fl_Hold_Browser *obj = new Fl_Hold_Browser(5, 25, 840, 350);
 obj->textfont(FL_COURIER);
 sprintf(line, "Set genetic code for %s", view->tot_sel_seqs > 1 ? "selected sequences" : view->seqname[num]);
 obj->copy_label(line);
 obj->align(FL_ALIGN_TOP);
 for(num = 0; num < totcodes; num++) {
-	sprintf(line, "%45.45s|%2d| %s", codencbinames[num], get_ncbi_gc_number(num), get_code_descr(num));
+	sprintf(line, "%65.65s|%2d| %s", get_code_target(num), get_ncbi_gc_number(num), get_code_descr(num));
 	obj->add(line);
 	}
 obj->value(get_acnuc_gc_number(gc) + 1);
