@@ -808,7 +808,7 @@ int i;
 char message[200];
 int old_phys;
   
-  Fl_PDF_or_PS_File_Device* surface = new Fl_PDF_or_PS_File_Device();
+  PDF_or_PS_File_Device* surface = new PDF_or_PS_File_Device();
   if (surface->start_job(matpt->plotname, printout_pageformat)) return;
 // we use bottom-up coords for PDF and PS output, it's rather tricky.  
 #ifndef NO_PDF
